/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Leopold, T., Skopek, J., and F. Schulz (2018). 
  Gender Convergence in Housework Time: A Life Course and Cohort Perspective
  Sociological Science. 		
  
  
  00_preparation.do
  
  Preparation of the original survey data of the SOEP, version 30. Note, that 
  our syntax utilizes the SOEPLong data provision (the long files). 
  
  For preparing the data we reused code developed for an earlier paper 
  Leopold, T., & Skopek, J. (2015). 
	Convergence or Continuity? The Gender Gap in Household Labor After Retirement. 
	Journal of Marriage and Family, 77, 819–832. http://doi.org/10.1111/jomf.12199
  
  
  Input: Original SOEPlong files (v.30).
  Output: temp/couplehousew.dta (couple data set, long format)
 

  Change log SOEP v.30
  http://www.diw.de/de/diw_02.c.238121.de/aenderungen_am_datensatz.html
  

http://about.paneldata.org/soep/dtc/data-structure.html
  Code	Meaning
-1	no answer / don’t know
-2	does not apply
-3	implausible value
-4	Inadmissable multiple response
-5	Not included in this version of the questionnaire
-6	Version of questionnaire with modified filtering
-8	Question not part of the survey program this year*


  Documentation on time-use items (H=housework, E=errands, R=repairs, C= childcare)
  (important note: until 1990 Housework and Errands have been surveyed together in one item; 
  1984 even together with childcare)			

	1984	H&E&C, R	
	1985	H&E, C, R
	1986	H&E, C, R
	1987	H&E, C, R
	1988	H&E, C, R
	1989	H&E, C, R
	1990	H&E, C, R  		NOTE EAST: H, E, R, C !
	1991	H, E, R, C
	1992	H, E, R, C
	1993 	H, E, R, C
	1994	H, E, R, C
	1995	H, E, R, C
	1996	H, E, R, C
	1997	H, E, R, C
	1998	H, E, R, C
	1999	H, E, R, C
	2000	H, E, R, C
	2001	H, E, R, C
	2002	H, E, R, C
	2003	H, E, R, C
	2004	H, E, R, C
	2005	H, E, R, C
	2006	H, E, R, C
	2007	H, E, R, C
	2008	H, E, R, C
	2009	H, E, R, C
	2010	H, E, R, C
	2011	H, E, R, C
	2012	H, E, R, C
	2013	H, E, R, C
	2014	H, E, R, C
	2015	H, E, R, C
	2016	H, E, R, C
	
	Documentation on time use items for Weekend hours: 
	1984	H&E&C, R	-> sunday or holiday	
	1985	H&E, C, R	-> sunday
	1986	H&E, C, R	-> sunday
	1987	H&E, C, R	-> sunday
	1988	H&E, C, R	-> sunday
	1989	H&E, C, R	-> sunday
	1990	H&E, C, R	-> sunday, saturday  NOTE EAST: H, E, R, C !
	1991	n.a.
	1992	H, E, R, C	-> sunday
	1993 	H, E, R, C	-> sunday, saturday
	1994	n.a.
	1995	H, E, R, C	-> sunday, saturday
	1996	n.a.
	1997	H, E, R, C	-> sunday, saturday
	1998	n.a.
	1999	H, E, R, C	-> sunday, saturday
	2000	n.a.
	2001	H, E, R, C	-> sunday, saturday
	2002	n.a.
	2003	H, E, R, C	-> sunday, saturday
	2004	n.a.
	2005	H, E, R, C	-> sunday, saturday
	2006	n.a.
	2007	H, E, R, C	-> sunday, saturday
	2008	n.a.
	2009	H, E, R, C	-> sunday, saturday
	2010	n.a.
	2011	H, E, R, C	-> sunday, saturday
	2012	H, E, R, C	-> sunday, saturday
	2013	H, E, R, C	-> sunday, saturday
	2014	n.a.
	2015	H, E, R, C	-> sunday, saturday
	2016	n.a.
	
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

// configuration file
run config 

set more off


/*-----------------------------------------
  Prepare Time use data
  - a variable 
		housew = hours in domestic labor  + errands (comparable from 1985 upwards) 
  – child care hours
-----------------------------------------*/


// Note: person long file is huge. Select only relevant variables. 
use pid syear pli0043 pli0041 	/// housework (hours on weekday)
			  pli0042			/// housework, CC, err. (hours on weekday) --> only 1984 -> not used! 
			  pli0040 			/// errands (hours on weekday)
			  pli0044 pli0045 	/// childcare (hours on weekday)
			  pli0047 			/// education and further education (hours on weekday)
			  pli0049 pli0050 	/// repairs, gardening, etc. (hours on weekday)
			  pli0051 			/// hobbies, spare time (hours on weekday)
			  pli0038 pli0037 pli0039 /// job, side-job, training (hours on weekday)
			  pli0016 pli0015 pli0017 /// housework (sunday)
			  pli0012 pli0013 pli0014 /// housework (saturday)
			  pli0011				  /// errands (sunday)	
			  pli0054				  /// errands (saturday)	
			  pli0018-pli0020		  /// Childcare (saturday)
			  pli0021-pli0023		  /// Childcare (sunday)
			  pli0030-pli0032 		  /// repairs (Saturday)
			  pli0033-pli0035 		  /// repairs (Sunday)
			  using  "${data}/pl", clear

count	// 482,288 person-year records
			  
* check consistency of sorting 
isid pid syear

/*-----------------------------------------
  Time use items
-----------------------------------------*/
  
// Notes on coding of time use variables in the SOEP:
// - housework and errands have been asked jointly in one item from survey year 1985-1990
// - in 1984 housework, errands, and child care have been asked jointly (hence, we will exclude year 1984 later for our purpose)
// - housework  is provided in two variables pli0041 & pli0043 
//		pli0041 is only available for 1990 and is filled if pli0043 < 0
assert pli0043==-2 if pli0041 > 0
// - repairs: two variables as well: pli0049 pli0050; pli0050 only available for 1990
//	   pli0050 equals pli0049 if pli0050 > 0			
assert pli0049==pli0050 if pli0050>0


/////////////////////////
// Coding: ERRANDS
/////////////////////////	 
tab pli0040 syear if inrange(syear, 1984,1990), miss // 1984 - 1990, this item was asked differently
tab pli0040 syear if inrange(syear, 1991,2000), miss

recode pli0040 (-8 = .) (-5 = .) // "." means here, not included in the questionnaire 

// time use: errands
gen hrserr = pli0040 
drop pli0040
lab var hrserr "time use: errands (weekday)"

// Weekend: errands
* Sunday
tab pli0011 syear if inrange(syear, 1984,1990), miss
tab pli0011 syear if inrange(syear, 1991,2000), miss
tab pli0011 syear if inrange(syear, 2001,2010), miss
tab pli0011 syear if inrange(syear, 2011,2015), miss
recode pli0011 (-8 = .) (-5 = .)
gen hrserr_sun = pli0011
drop pli0011
lab var hrserr_sun "time use: errands (sunday)"
* Saturday 
tab pli0054 syear if inrange(syear, 1984,1990), miss
tab pli0054 syear if inrange(syear, 1991,2000), miss
tab pli0054 syear if inrange(syear, 2001,2010), miss
tab pli0054 syear if inrange(syear, 2011,2015), miss
recode pli0054 (-8 = .) (-5 = .)
gen hrserr_sat = pli0054
drop pli0054
lab var hrserr_sat "time use: errands (saturday)"

/////////////////////////
// Coding: HOUSEWORK
/////////////////////////	 
tab pli0043 syear if inrange(syear, 1984,1990), miss // 1990 – strange –> too many "2s"
tab pli0043 syear if inrange(syear, 1991,2000), miss 

// alternative item: pli0041 has been asked only 1990!
tab pli0041 syear if inrange(syear, 1984,1990), miss 
tab pli0041 syear if inrange(syear, 1991,2000), miss
tab pli0041 syear if inrange(syear, 2001,2010), miss
tab pli0041 syear if inrange(syear, 2011,2015), miss
recode pli0041 (-8 = .) (-5 = .)  // "." means here, not included in the questionnaire 

// time use: housework
recode pli0043 (-8 = .) (-5 = .)
gen hrshw = pli0043 
tab hrshw syear if inrange(syear, 1984,1990), miss 
tab hrshw syear if inrange(syear, 1990,2000), miss 
tab hrshw syear if inrange(syear, 2001,2010), miss 
tab hrshw syear if inrange(syear, 2011,2015), miss // 2013 – code: 5? => not included in the questionnaire (maybe a sub sample didn't get it)
* replace hours with valid values from alternative item in 1990
replace hrshw = pli0041 if syear==1990 & hrshw < 0  & pli0041!=. // 5575 cases

* check distributions
tabstat pli0041 pli0043 hrshw, stat(mean p25 p50 p75 N) col(stats)
drop pli0041 pli0043
lab var hrshw "time use: housework (weekday)"

// Weekend: Housework
* Sunday
// note: pli0016 pli0015 pli0017
recode pli0015 (-8 = .) (-5 = .) // -> only 1990
recode pli0016 (-8 = .) (-5 = .)
recode pli0017 (-8 = .) (-5 = .) // -> only 1990
gen hrshw_sun = pli0016
replace hrshw_sun = pli0015 if syear==1990 & hrshw_sun < 0  & pli0015<.
replace hrshw_sun = pli0017 if syear==1990 & hrshw_sun < 0  & pli0017<.
drop pli0015-pli0017
lab var hrshw_sun "time use: housework (sunday)"
* Saturday
// note: pli0012 pli0013 pli0014 
// pli0013 pli0014 -> only 1990
recode pli0012 (-8 = .) (-5 = .)
recode pli0013 (-8 = .) (-5 = .)
recode pli0014 (-8 = .) (-5 = .)
gen hrshw_sat = pli0012
replace hrshw_sat = pli0013 if syear==1990 & hrshw_sat < 0  & pli0013<.
replace hrshw_sat = pli0014 if syear==1990 & hrshw_sat < 0  & pli0013<.
drop pli0012 pli0013 pli0014 
lab var hrshw_sat "time use: housework (saturday)"


/////////////////////////
// Coding: CHILD CARE
/////////////////////////	 
tab pli0044 syear if inrange(syear, 1984,1990), miss  // not included in 1984
tab pli0044 syear if inrange(syear, 1990,2000), miss 
tab pli0044 syear if inrange(syear, 2001,2010), miss 
tab pli0044 syear if inrange(syear, 2011,2015), miss // 2013 – code: 5? => not included in the questionnaire (maybe a sub sample didn't get it)

recode pli0044 (-8 = .) (-5 = .) // "." means here, not included in the questionnaire 
gen hrscc = pli0044 

// Alternative variable 
tab pli0045 syear if inrange(syear, 1984,1990), miss  // only included in 1990
tab pli0045 syear if inrange(syear, 1991,2000), miss 
tab pli0045 syear if inrange(syear, 2001,2010), miss 
tab pli0045 syear if inrange(syear, 2011,2015), miss // 2013 – code: 5? => not included in the questionnaire (maybe a sub sample didn't get it)
recode pli0045 (-8 = .) (-5 = .)  // "." means here, not included in the questionnaire 
replace hrscc = pli0045 if syear==1990 & hrscc < 0  & pli0045!=. // 3615 cases

* check distributions
tabstat pli0044 pli0045 hrscc, stat(mean p25 p50 p75 N) col(stats)

drop pli0044 pli0045
lab var hrscc "time use: childcare (weekday)"

// Weekend: child care
* Sunday
recode pli0021 (-8 = .) (-5 = .) // -> 1990 only
recode pli0022 (-8 = .) (-5 = .)
recode pli0023 (-8 = .) (-5 = .) // -> 1990 only
gen hrscc_sun = pli0022
replace hrscc_sun = pli0021 if syear==1990 & hrscc_sun < 0  & pli0021<.
replace hrscc_sun = pli0023 if syear==1990 & hrscc_sun < 0  & pli0023<.
drop pli0021-pli0023
lab var hrscc_sun "time use: childcare (sunday)"
* Saturday
recode pli0018 (-8 = .) (-5 = .) // -> 1990
recode pli0019 (-8 = .) (-5 = .)
recode pli0020 (-8 = .) (-5 = .) // -> 1990
gen hrscc_sat = pli0019
replace hrscc_sat = pli0018 if syear==1990 & hrscc_sat < 0  & pli0018<.
replace hrscc_sat = pli0020 if syear==1990 & hrscc_sat < 0  & pli0020<.
drop pli0018-pli0020
lab var hrscc_sat "time use: childcare (saturday)"

/////////////////////////
// Coding: REPAIRS
/////////////////////////
tab pli0049 syear if inrange(syear, 1984,1990), miss  // not included in 1984
tab pli0049 syear if inrange(syear, 1991,2000), miss 
tab pli0049 syear if inrange(syear, 2001,2010), miss 
tab pli0049 syear if inrange(syear, 2011,2015), miss // 2013 – code: 5? => not included in the questionnaire (maybe a sub sample didn't get it)
recode pli0049 (-8 = .) (-5 = .) 
// time use: repairs
gen hrsrep = pli0049 

// Alternative variable: pli0050
tab pli0050 syear if inrange(syear, 1984,1990), miss // only included in 1990
tab pli0050 syear if inrange(syear, 1991,2000), miss 
recode pli0050 (-8 = .) (-5 = .) 

replace hrsrep = pli0050 if syear==1990 & hrsrep < 0  & pli0050!=. // 2286 cases
* check distributions
tabstat pli0049 pli0050 hrsrep, stat(mean p25 p50 p75 N) col(stats)

drop pli0049 pli0050
lab var hrsrep "time use: repairs (weekday)"

* recode -2 missings (does not apply) in time-use items to zero hours
foreach var of varlist hrserr hrshw hrscc hrsrep {
	replace `var' = 0 if `var'==-2
}

* recode missings
// Note on missing codes and conversion to stata missings: 
// -3	not valid						==> .c
// -2	does not apply				==> .b NOTE: zero was entered for that in some questionnaires
// -1	not specified					==> .a
mvdecode hrs*, ///
		 mv(-1 = .a \ -2 = .b \ -3 = .c)

/*
 Post-coding of TIME USE VARIABLES
*/
// gen a variable indicating survey year 1990 or before
gen sy1990 = syear <= 1990
lab var sy1990 "Survey year 1990 or before"


tab hrserr syear if inrange(syear, 1984,1990), miss
tab hrserr syear if inrange(syear, 1991,2000), miss
tab hrserr syear if inrange(syear, 2001,2010), miss
tab hrserr syear if inrange(syear, 2011,2015), miss

tab hrshw syear if inrange(syear, 1984,1990), miss
tab hrshw syear if inrange(syear, 1991,2000), miss
tab hrshw syear if inrange(syear, 2001,2010), miss
tab hrshw syear if inrange(syear, 2011,2015), miss

tabstat hrshw, by(syear) stats(mean min max) f(%9.1f)
tabstat hrshw_sat, by(syear) stats(mean min max) f(%9.1f)
tabstat hrshw_sun, by(syear) stats(mean min max) f(%9.1f)
tabstat hrserr_sat, by(syear) stats(mean min max) f(%9.1f)
tabstat hrserr_sun, by(syear) stats(mean min max) f(%9.1f)
/*
syear	mean
	
1984	4.3	=> bias! All housework, repairs and errands all jointly asked
1985	2.6 => E&HW
1986	2.5 => E&HW
1987	2.5 => E&HW
1988	2.5 => E&HW
1989	2.5 => E&HW
1990	2.4 => E&HW
1991	1.9 => separatedly!
1992	1.9
1993	1.9
1994	1.9
*/

// generate a new housework variable summing hours for routine housework and errands
* Weekday
egen housew = rowtotal(hrserr hrshw) // treats missing as zero
lab var housew "Housework (routine + err, weekday)"
gen housew_miss = mi(hrserr) & mi(hrshw) // mark cases with missing data in either item
// correct: set to missing if questions were not asked (. -> code 8 or 5: note for "does not apply", zero was entered)
replace housew = . if hrserr==. & hrshw == .

* Sunday
egen housew_sun = rowtotal(hrserr_sun hrshw_sun) // treats missing as zero
gen housew_sun_miss = mi(hrserr_sun) & mi(hrshw_sun)
replace housew_sun = . if hrserr_sun==. & hrshw_sun == .
lab var housew_sun "Housework (routine + err, sunday)"

* Saturday
egen housew_sat = rowtotal(hrserr_sat hrshw_sat) // treats missing as zero
gen housew_sat_miss = mi(hrserr_sat) & mi(hrshw_sat)
replace housew_sat = . if hrserr_sat==. & hrshw_sat == .
lab var housew_sat "Housework (routine + err, saturday)"

tabstat housew, by(syear) stats(mean min max) f(%9.1f)
tabstat housew_sat, by(syear) stats(mean min max) f(%9.1f)
tabstat housew_sun, by(syear) stats(mean min max) f(%9.1f)

// Childcare - treat "does not apply" as zero! 
replace hrscc = 0 if hrscc == .b
replace hrscc_sat = 0 if hrscc_sat == .b
replace hrscc_sun = 0 if hrscc_sun == .b

/*
syear	mean
	
1984	3.1
1985	2.6
1986	2.5
1987	2.5
1988	2.5
1989	2.5
1990	2.9
1991	2.9
1992	3.0
1993	3.0
1994	3.0
1995	2.9
*/
// drop year 1984 (non comparable measures)
drop if syear== 1984 

// keep only relevant variables 
keep syear pid housew* hrscc* sy1990
tempfile pl
save `pl', replace



/*-----------------------------------------
  Generated variables on person level ("pgen")
  - educational level
  - employment state (current)
  - effective working hours per week
  - current net income
  - labor force experience
  - ISEI
-----------------------------------------*/
// note: load file with generated person-level variables
use pid syear pgbilzeit pgcasmin pgisced97 pgisced11 /// educational level (CASMIN and ISCED-97 scales)
			  pgemplst /// current employment state
			  pglfs /// Labor force status
			  pgtatzeit  /// effective working hours per week (not contractual hours)
			  pglabnet /// current net income (including imputed values) in Euro
			  pgisei88 /// ISEI
			  pgpartz /// partner cursor
			  pgexpft /// Working experience, full-time employment
			  using "${data}/pgen", clear
/*
 Doc labor market experience
 
 pgexpft:
 This variable reflects the total length of full-time
 employment in the respondentís career up to the point of the
 interview in a given year. The variable is created by
 combining monthly information on employment status from the
 calendar dataset ARTKALEN (which provides monthly information
 on activity status since an individual entered the SOEP) and
 annual information from the biographical dataset PBIOSPE
 (which provides information on activity status over the
 individualís life course). EXPFT$$ gives the length of time in
 years with months in decimal form.

 Persons whose life course has been observed completely but
 with no spell of full-time employment are assigned the code
 (0). The code (-1) is assigned to all persons whose life
 course has not been observed completely. Persons with
 inconsistent information receive a (-3).
 
 pgexppt:
 Part-time working experience:
 This variable reflects the total length of part-time
 employment in the respondentís career up to the point of the
 interview in a given year.
 

*/
count // 567,130 person-year records			  
			  
* check consistency of sorting
isid pid syear


* recode missings
// Note on missing codes and conversion to stata missings: 
// -5 	not included in questionnaire	==> .b
// -3	not valid						==> .c
// -2/-8	does not apply				==> .b
// -1	not specified					==> .a
mvdecode pg*, ///
		 mv(-1 = .a \ -2 = .b \ -8 = .b \ -5 = .b \ -3 = .c)
// recode working hours "does not apply" to zero
recode pgtatzeit (.b=0)

recode pgpartz (0 = 0) (1/4 = 1), gen(partner)

* Working experience full time
sum pgexpft
mvdecode pg*, ///
		 mv(-1 = .a \ -2 = .b \ -8 = .b \ -5 = .b \ -3 = .c)
/*
Full-time working experience:
This variable reflects the total length of full-time employment in the 
respondent’s career up to the point of the interview in a given year. 
The variable is created by combining monthly information on employment status 
from the calendar dataset ARTKALEN (which provides monthly information on activity 
status since an individual entered the SOEP) and annual information from the 
biographical dataset PBIOSPE (which provides information on activity status over 
the individual’s life course). EXPFT$$ gives the length of time in years with 
months in decimal form.

Persons whose life course has been observed completely but with no spell of 
full-time employment are assigned the code (0). The code (-1) is assigned to 
all persons whose life course has not been observed completely. Persons with 
inconsistent information receive a (-3).
*/		 

tempfile pgen
save `pgen'


/*-----------------------------------------
  Prepare pequiv file 
  (see the pequiv documentation) 
-----------------------------------------*/
use "${data}/pequiv", clear
// fre h11101 d11105 d11107 d11106 d11109 e11102 e11103 e11104
keep pid syear i11210 y11101 d11106 d11107 i11202 e11103 i11110 h11101-h11110 e11101 m11125 h11101 d11105 d11107 d11106 d11109 e11102 e11103 e11104 d11104 d11108 i11102 m11126 w11101 w11103

* Annual Work Hours of Individual
/*
Annual hours worked in the previous year is calculated by adding together the 
estimated annual hours of full-time, part-time (including marginal employed), 
vocational training and short-time work. Annual hours of work in each of these 
four states is calculated by multiplying the average number of hours worked 
per week by the number of months worked in each of these three states for the 
previous year and by 4.33 (the average number of weeks per month). No correction 
for vacation or diseases has been made.
-1 = N/A - Child
0 = Not employed in the previous year
The value of this variable ranges from 1 to 7457.

*/
mvdecode e11101  , ///
		 mv(-1 = .a \ -2 = .b \ -8 = . \ -5 = . \ -3 = .c)
sum e11101
// recover average week day working hours (devide by 12 months, 4.33 weeks, 5 days)
gen wkhrs = e11101*(1/12)*(1/4.33)*(1/5)
sum wkhrs if wkhrs > 0  // 7.1 hrs per day, about 35 hours per week

* satisfaction with health
fre m11125
mvdecode m11125, ///
		 mv(-1 = .a \ -2 = .b \ -8 = . \ -5 = . \ -3 = .c)
// This variable indicates satisfaction with health at the time of the survey for all indi- viduals in the household 16 years of age and older.
		 
* Marital status
fre d11104
// This variable indicates the marital status in the current survey year of all 
// individuals in the household 16 years of age and older.
// -1 = N/A – Child / Item non-response (child is age < 16)
mvdecode *, ///
		 mv(-1 = .a \ -2 = .b \ -8 = . \ -5 = . \ -3 = .c)
* Relationship to the HH head
fre d11105
// This variable indicates the individual's relationship to the current survey year’s head of household.
// The relation to head variable is created by collapsing the SOEP relationship 
// to head variable into 5 categories. These categories include spouses, life-partners, 
// children, foster children, siblings, parents, in-laws, grandchildren, other relatives, 
// and unrelated persons. Since 2012 (wave 29) the original SOEP variable collects more 
// detailed information about family relationships.
// -1 = Item non-response

* Number of persons in HH
fre d11106
// Indicates the number of persons in the household at the time of the interview.
// This information is obtained from the household head or another household member 
// who knows about the household's composition.

* Number of children in HH 
fre d11107
// Indicates the number of persons in the household under age of 18 at the time of the interview.
// This variable is created by computing the number of individuals in the household under the age of 18.

* Number of hh members age 0-14 
fre h11101

* Education with respect to High school
fre d11108
// This variable indicates the highest level of education (less than high school, 
// completed high school, or more than high school) of all individuals in 
// the household 16 years of age and older.
// individual level measure
/*
Less than High School = 
Intermediate secondary school (Realschule), Lower secondary school (Hauptschule), Other, None

High school = 
Upper secondary school degree giving access to university studies (Abitur)
Certificate of aptitude for specialized short-course higher education (Fachhochschulreife)
Apprenticeship (Lehre)
Specialized vocational school (Berufsfachschule)

More than high school = 
School of health care (Schule des Gesundheitswesens)
Specialized college of higher education, post-secondary technical (Fachhochschule)
College
Technical university usually requiring practical training as part of the studies (Technische Universität)
Civil service training
*/

* Number of Years of Education
fre d11109

// This variable indicates the number of years of education completed at the time 
// survey for all individuals in the household 16 years of age and older.
// Individuals with a school leaving degree are assigned a minimum of between 9 
// and 12 years of education. Individuals with a vocational degree are assigned an 
// additional 2 to 3.5 years of education. Individuals who attended a technical 
// college are assigned an additional 4 years of education. If an individual 
// received a vocational college de- gree or attended a university outside of 
// the FRG then the individual is assigned a total of 18 or 19 years of education. 
// For more information about the construction of this variable see Couch, 1994.

// -1 = N/A – Child / Item non-response

* Employment status of individual (based on working hours and wage in previous year) 
fre e11102
// This variable indicates employment status in the previous year for all 
// individuals in the household 16 years of age and older.
// If the individual had positive wages in the previous year and worked at least 
// 52 hours then the individual was employed. Otherwise, the individual was not employed.

* Employment Level of Individual (during previous year) 
fre e11103 
// This variable indicates whether any individual in the household 16 years of age 
// and older worked full-time, part-time, or not at all in the previous year.
// If the individual had positive wages and worked at least 1,820 hours last year 
// (35 hours per week on average), then the individual was employed full-time. 
// If the individual had positive wages and worked at least 52 hours but less 
// than 1,820 hours last year, then the individual was employed part-time. 
// Otherwise, the individual was not working

* Primary Activity of Individual (time of survey) 
fre e11104
// This variable indicates primary activity at the time of the survey for all 
// individuals in the household 16 years of age and older.
// This variable is based on the individual's self-reported employment status at the time of the interview.
// If the individual reported being full-time, part-time, or marginally employed, 
// having short-time work, performing military/civilian service, on maternity leave, 
// or being engaged in in-company training then the individual is considered to be working now. 
// If the individual reported not being employed or being unemployed then the individual is 
// considered to be not working now.
// Unemployed is not a category in the recoded variable because in the original 
// data individuals were able to choose unemployed as their employment status in 1984 through 1990 only.


* indiviudal labor earnings (annual)
sum i11110
// Labor earnings include wages and salary from all employment including training, 
// primary and secondary jobs, and self-employment, plus income from bonuses, overtime, and profit-sharing.
// Specifically labor earnings is the sum of income from primary job, 
// secondary job, self-employment, 13th month pay, 14th month pay, 
// Christmas bonus pay, holiday bonus pay, miscellaneous bonus pay, and profit-sharing income.
// NOTE: This variable is in current year EURO! period Annual

* HH Post Government income 
sum i11102 

// This variable represents the combined income after taxes and government transfers 
// in the previous year of all individuals in the household.
// Annual periodicity. 

* Current selfrated health status
fre m11126
// This variable indicates each person’s self-rated health status.
// -2 = N/A - Child
tempfile pequiv

* Individual cross-sectional weight w11101 (they vary between waves!)
sum w11101
/*
Indicates the individual's population and sample weight. The individual weight 
provides a time-series consistent information, which might be used for analyses 
of income and income inequality over time. Given the selectivity built in the 
answering behavior of first-time respondents with respect to income questions 
(showing a signif- icant higher share of item-non response which is especially 
true for a first wave of a new sub-sample), this weighting factor excludes every 
first wave of a new sub-sample of the SOEP. If all sub-samples will be used, 
the appropriate variable is W11105$$.
*/
* Individual longitudinal weight
sum w11103
// Indicates the individual's longitudinal sample weight.
/*
Longitudinal weights in the SOEP are constructed using inverse staying factors. 
The staying factor is the inverse of the probability that an individual participated 
in the named year. By themselves, W11103$$ are only staying factors.

To properly weight a balanced sample of individuals represented in five years of the survey (1986 through 1990), 
for example, create a longitudinal weight by multiplying the individual weight in 1986 by 
the staying factors in 1987, 1988, 1989, and 1990.

Example:
longitudinal weight = W1110186*W1110387*W1110388*W1110389*W1110390

The created longitudinal weight should be used with any longitudinal sample.
*/

save `pequiv'

/*-----------------------------------------
  
  Cohabitation history (create a variable measuring cumulative years of cohabitation) 
  
  Prepare BIOMARSY
  
-----------------------------------------*/
/*
use "${data}/BIO_WIDE_FILES/biomarsy", clear

mvdecode spelltyp, ///
		 mv(-1 98 99 = .a \ -3 = .c)
mvdecode beginy endy, ///
		 mv(-1 = .a \ -3 = .c)
		 
keep persnr spellnr spelltyp beginy endy		 

// do a year-based split and create a variable equivalent to syear
gen dur = endy - beginy + 1
drop if dur == .
expand dur, gen(original)
sort persnr spellnr original
by persnr spellnr (original), sort: gen syear = beginy if _n==1
by persnr spellnr (original), sort: replace syear = beginy + _n-1 if _n>1
// identify being married or living in a same-sex union 
gen married = inlist(spelltyp, 2, 7) if spelltyp < .
// set cohabitation to missing if spelltype unkown
replace married = 0 if spelltyp >= .

// collapse to unique yearly information
keep persnr syear married
collapse (sum) married, by(persnr syear)
* per year max 1 cohab years
replace married = 1 if married > 1 & married < .

// create a cumulative counter
by persnr (syear), sort: gen summary = sum(married)

rename persnr pid 
lab var summary "Cumulated years of marriage"
keep pid syear summary

tempfile marriage 
save `marriage' , replace
*/
/*-----------------------------------------
  Prepare BIOBIRTH (Women) 
  
  Variables 
	SUMKIDS
	Age of youngest child
  
  CAUTION: It seems that in the recent release BIOBIRTHM has been integrated into 
		   BIOBIRTH. 
  
  The file BIOBIRTH is based on every woman who has ever had at least one 
  successful SOEP interview. For each of these women the data set BIOBIRTH 
  documents the birth biography. The annual update focuses on including new 
  information on giving-birth collected in the individual questionnaire or 
  in the biographical questionnaire. Furthermore women who have been interviewed 
  for the first time but who have no information on giving-birth yet are 
  included. The latter are either new female household members or female teenagers 
  who have reached the required minimum for a SOEP participation (16 years). 
  For that reason BIOBIRTH can be described as an accumulative data set, in which 
  the entire birth biography of all female SOEP respondents is presented. 
  BIOBIRTH covers the following information:
  
  
  SUMKIDS 
	Total number of children born (more precisely: total number of children 
	identifiable within SOEP by merging all available data up to the time of the 
	last observation (SUMKIDS=BIOKIDS+NEWKIDS).
  
  BIOKIDS 
	Total number of children identified through the birth biography. For women 
	who haven’t filled in the birth biographical questionnaire yet, the code “-2” applies.
	
-----------------------------------------*/
/*
use "${data}/BIO_WIDE_FILES/biobirth", clear

// no missings for sumkids
fre sumkids

// year of birth for youngest child
mvdecode kidgeb*, ///
		 mv(-1 = .a \ -2 = .b \ -3 = .c)

// there are also men included! 
fre sex 

rename persnr pid
keep pid sumkids kidgeb*

tempfile biobirth
save `biobirth'
*/

/*-----------------------------------------
  Prepare household level data
-----------------------------------------*/

use "${data}/hgen", clear

keep hid syear hgsize

* Size Of Housing Unit In Sq M
sum hgsize

mvdecode *, ///
		 mv(-1 = .a \ -2 = .b \ -8 = . \ -5 = . \ -3 = .c)
		 
tempfile hgen
save `hgen'

use "${data}/hl", clear

keep hid syear hlf0159 hlf0217 hlf0214 hlf0225
// note: -2 is recoded to 0 appliance not in HH!
recode hlf0159 hlf0217 hlf0214 hlf0225 (-2=0)
mvdecode *, /// 
		 mv(-1 = .a \  -8 = . \ -5 = . \ -3 = .c)

tab syear hlf0159, miss
tab syear hlf0159,  row
tab syear hlf0217,  row
tab syear hlf0214,  row
tab syear hlf0225,  row

tempfile hl 
save `hl'	


/*-----------------------------------------
  pbrutto file
-----------------------------------------*/
use "${data}/pbrutto", clear

	 
/*-----------------------------------------
  Path file
-----------------------------------------*/

// load person path file (includes all sample members and cursors to partners)
use "${data}/ppfadl", clear

* keep only relevant variables
keep pid hid eintritt parid  partner sex syear netto gebjahr sampreg wave parid iyear psample loc1989 germborn pbleib phrf  migback

* recode missing values (-2 does not apply; -1 = unclear)
mvdecode *, ///
		 mv(-1 = .a \ -2 = .b \ -8 = .b \ -5 = .b \ -3 = .c)

// add generated variables and housework stuff
merge 1:1 pid syear using `pgen', assert(matched master) nogen
merge 1:1 pid syear using `pl', assert(matched master) nogen
merge 1:1 pid syear using `pequiv', assert(matched master) nogen
merge n:1 hid syear using `hgen', assert(matched master) nogen
merge n:1 hid syear using `hl', assert(matched master) nogen
// merge 1:1 pid syear using `marriage', keep(matched master) nogen // due to the retrospection, there are some additional using cases - do not keep them
// merge n:1 pid  using `biobirth', assert(matched master) nogen 

// add partner variables (extract from pequiv)
preserve 
	use `pequiv' , clear
	// keep only these partner variables 
	keep pid syear wkhrs e11103 d11108 d11109 e11101 e11102 e11103 e11104 i11102 i11110
	foreach var of varlist wkhrs d11108 d11109 e11101 e11102 e11103 e11104 i11102 i11110 {
		rename `var' P`var'
	}
	rename pid parid
	tempfile partner
	save `partner'
restore 
merge n:1 parid syear  using `partner', keep(matched master) nogen 

// add partner variable pgbilzeit (extract from pgen)
// note: that was used to check if this can compensate the relatively large number of missings in the education variable in pequiv. Yet, the variable is identical. Hence, actually no need for pgbildzeit. 
preserve 
	use `pgen' , clear
	// keep only these partner variables 
	keep pid syear pgbilzeit
	foreach var of varlist pgbilzeit {
		rename `var' P`var'
	}
	rename pid parid
	tempfile partner
	save `partner', replace
restore 
merge n:1 parid syear  using `partner', keep(matched master) nogen 


* Age
gen gebj = gebjahr
gen age = syear - gebj
* Housework
gen hw = housew

// save
save "${tempDir}/00_prepare", replace
