/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Leopold, T., Skopek, J., and F. Schulz (2018). 
  Gender Convergence in Housework Time: A Life Course and Cohort Perspective
  Sociological Science. 		
  
  02_analyses.do 
  
  All analyses in the manuscript based on the preferred model (8b, 
  see appendix do-file for model selection). 
  
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/


do config

use "${tempDir}/01_pool_samples", clear

unique pid // 20777, 227140


// SOEP samples (West Germany)
fre psample if !mi(hw)

// indiviudals and observations
unique pid if !mi(hw)

// Women and observations
unique pid if male==0 & !mi(hw)

// Men and observations
unique pid if male==1 & !mi(hw)

// Panel data 
xtset pid syear
* Max 31 observations, 50% have 7 or less, survey year 1985-2015 
xtdes if !mi(hw) // n=20109 individuals
count if !mi(hw) // N=201,261 observations
count if mi(hw) // 25,879
// % mi
misstable patt hw 

// average waves per respondent 
di 201261/20109



///////////////
// Tables 1 and 2
// TABLE 1. DESCRIPTIVE STATISTICS – WOMEN
// TABLE 2. DESCRIPTIVE STATISTICS – MEN
///////////////
/*
Note: these tables show absolute case numbers (no listwise deletion), 
and averages for selected variables (no listwise deletion). 
Case numbers are lower for the estimation due to missing values in housework hours. 
*/


recode gebjahr (1920/1929 = 1 "1920-1929") ///
			   (1930/1939 = 2 "1930-1939") ///
			   (1940/1949 = 3 "1940-1949") ///
			   (1950/1959 = 4 "1950-1959") ///
			   (1960/1969 = 5 "1960-1969") ///
			   (1970/1979 = 6 "1970-1979") ///
			   (1980/1989 = 7 "1980-1989") ///
			   (else = .) ///
			   , gen(cohort)
recode age 		(20/29 = 1 "20-29") /// 
				(30/39 = 2 "30-39") /// 
				(40/49 = 3 "40-49") /// 
				(50/59 = 4 "50-59") /// 
				(60/69 = 5 "60-69") /// 
				(70/79 = 6 "70-79") /// 
				(80/89 = 7 "80-89") /// 
				(else = .) ///
				, gen(agegrp)

* Prepare a matrix for each table. 
foreach sex of numlist 1 2 {
	
	capt mat drop mS`sex'
	
	foreach cohort of numlist 1/7 {
		capt mat drop mS`sex'C`cohort'
		foreach age of numlist 1/7 {
			
			capt estpost sum cohab d11107 yed wkhrs pgexpft noexpft if sex == `sex' & cohort == `cohort' & agegrp == `age', meanonly quietly
			if _rc > 0 {
				mat m =  [.,.,.,.,.,.,.]'
				// mat mS`sex'C`cohort'A`age' = [.,.,.,.,.,.,.]'
			}
			else {
				mat m = (e(N), e(mean)) 
				mat m = m'
				// mat mS`sex'C`cohort'A`age' = m
			}
			
			mat mS`sex'C`cohort' = nullmat(mS`sex'C`cohort') , m
		}
		
		
		* add a top row
		
		mat mS`sex'C`cohort' = (.,.,.,.,.,.,.) \ nullmat(mS`sex'C`cohort')
		
		estpost tabstat gebjahr if cohort == `cohort', stats(min max)
		
		mat min = e(min)
		mat max = e(max)
		local min = min[1,1]
		local max = max[1,1]
		
		mat rownames mS`sex'C`cohort' = "`min'-`max'" /// 
							 "N" ///
							 "Partner" ///
							 "Children" ///
							 "Education" ///
							 "Workhours" ///
							 "Years_full" ///
							 "Never_full" 
		/*					 
		mat rownames mS`sex'C`cohort' = "`min'-`max'" ///
							 "N (obs.)" ///
							 "Partner in household (fraction)" ///
							 "Children in household (#)" ///
							 "Years of education" ///
							 "Daily work hours" ///
							 "Years worked full time (#)" ///
							 "Never worked full time (fraction)" 
		*/
		mat mS`sex' = nullmat(mS`sex') \ mS`sex'C`cohort'		
		
		mat colnames mS`sex' = 20-29 30-39 40-49 50-59 60-69 70-79 80-89
		
	}
	
}

// Table 1 --> excel
putexcel set "${logDir}/Table_1.xlsx", replace
putexcel A1=matrix(mS2), names 

// Table 2 --> excel
putexcel set "${logDir}/Table_2.xlsx", replace
putexcel A1=matrix(mS1), names



///////////////
// Table 3
// TABLE 3. HIERARCHICAL LINEAR MODELS FOR CHANGE IN HOUSEWORK TIME
///////////////

// re-fit Model 8b

* WOMEN 
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj i.sy1990 if male == 0 || pid: cage, cov(uns)
mat g = e(N_g)
estadd scalar Individuals = g[1,1] 
estadd scalar Obs_per_Ind = e(N)/g[1,1] 
estadd scalar Min = 1
estadd scalar Max = 31

est store Wm8b

* MEN 
mixed hw c.cgebj c.cgebj2 c.cage c.cage2 c.cage3 c.cage4 c.cage#c.cgebj c.cage2#c.cgebj i.sy1990 if male == 1 || pid: cage, cov(uns)
mat g = e(N_g)
estadd scalar Individuals = g[1,1]
estadd scalar Obs_per_Ind = e(N)/g[1,1] 
estadd scalar Min = 1
estadd scalar Max = 31
est store Mm8b

estout Wm8b Mm8b, replace cell(b(f(%9.3f) star) se(f(%9.3f) par)) /// 
		varwidth(35) stats(N Individuals Obs_per_Ind Min Max ll, f(%9.1gc %9.1gc %9.1f %9.1g %9.1g %9.1gc)) lab nobase ///
		varlab(cgebj "Cohort" cgebj2 "Cohort^2" cage "Age" cage2 "Age^2" cage3 "Age^3" cage4 "Age^4" ///
			   c.cage#c.cgebj "Age x Cohort" c.cage2#c.cgebj "Age^2 x Cohort" 1.sy1990 "Survey year before 1991" _cons "Constant" ///
			   , elist(hw:_cons "{break}{hline @width}")) ///
			   transform(lns*: exp(2*@) 2*exp(2*@) atr*: tanh(@) (1-tanh(@)^2)) ///
			   eqlabels("" "Var(Age)" "Var(Constant)" "Corr(Age, Constant)" "Var(Resid)", none) ///
			   mlabels("Women" "Men", nonumbers) collabels(none) legend // mgroups(none)

estout Wm8b Mm8b using "${logDir}/Table_3.csv", replace cell(b(f(%9.3f) star) se(f(%9.3f) par)) /// 
		varwidth(35) stats(N Individuals Obs_per_Ind Min Max ll, f(%9.1gc %9.1gc %9.1f %9.1g %9.1g %9.1gc)) lab nobase ///
		varlab(cgebj "Cohort" cgebj2 "Cohort^2" cage "Age" cage2 "Age^2" cage3 "Age^3" cage4 "Age^4" ///
			   c.cage#c.cgebj "Age x Cohort" c.cage2#c.cgebj "Age^2 x Cohort" 1.sy1990 "Survey year before 1991" _cons "Constant" ///
			   ) ///
			   transform(lns*: exp(2*@) 2*exp(2*@) atr*: tanh(@) (1-tanh(@)^2)) ///
			   eqlabels("" "Var(Age)" "Var(Constant)" "Corr(Age, Constant)" "Var(Resid)", none) ///
			   mlabels("Women" "Men", nonumbers) collabels(none) legend style(tab)

estout Wm8b Mm8b using "${logDir}/Table_3.tex", replace cell(b(f(%9.3f) star) se(f(%9.3f) par)) /// 
		varwidth(35) stats(N Individuals Obs_per_Ind Min Max ll, f(%9.1gc %9.1gc %9.1f %9.1g %9.1g %9.1gc)) lab nobase ///
		varlab(cgebj "Cohort" cgebj2 "Cohort^2" cage "Age" cage2 "Age^2" cage3 "Age^3" cage4 "Age^4" ///
			   c.cage#c.cgebj "Age x Cohort" c.cage2#c.cgebj "Age^2 x Cohort" 1.sy1990 "Survey year before 1991" _cons "Constant" ///
			   ) ///
			   transform(lns*: exp(2*@) 2*exp(2*@) atr*: tanh(@) (1-tanh(@)^2)) ///
			   eqlabels("" "Var(Age)" "Var(Constant)" "Corr(Age, Constant)" "Var(Resid)", none) ///
			   mlabels("Women" "Men", nonumbers) collabels(none) legend style(tex)
			   		   
est restore Wm8b
est replay
est restore Mm8b
est replay


///////////////
// Numbers and calculations reported in the findings part. 
///////////////


// Calculations for results part 
/*

Maximum of gender specific housework functions

"Women’s peak ages were estimated at XX.X for the cohort of 1940, 
		XX.X for the cohort of 1950, and XX.X for the cohort of 1960, 
		equivalent to a decline of X months per cohort"
		
Formular: 
y = a + b1*c + b2*c^2 + b3*x + b4*x^2 + b5*x^3+ b6*x^4 + b7*x*c + b8*x^2*c 

Derivations: 

1st deriv
dy/dx = b3 + 2*b4*x + 3*b5*x^2+ 4*b6*x^3 + b7*c + 2*b8*x*c = 0

x*(2*b4 + 2*b8*c) + x^2 * (3*b5 + 4*b6*x) = - b3 - b7*c

2nd deriv 
dy/dxdx = 2*b4 + 2*3*b5*x + 3*4*b6*x^2 + 2*b8*c < 0

*/


* Define a program that does all the calculation
capt program drop peak_age
program define peak_age
	syntax, model(name) cohort(integer) [plot]
	
	* restore model
	est restore `model'
	
	* coefficients 
	mat cW = e(b)
	
	local mat "cW"
	
	#delimit ;
	
	// Solve iteratively
	foreach x of numlist 20(.1)80 { ;
		
		local val = `mat'[1,3] + 
		2*`mat'[1,4]*((`x' - 45)/10) + 
		3*`mat'[1,5]*((`x' - 45)/10)^2 + 
		4*`mat'[1,6]*((`x' - 45)/10)^3 + 
		`mat'[1,7]*((`cohort' - 1955)/10) + 
		2*`mat'[1,8]*((`cohort' - 1955)/10)*((`x' - 45)/10);
		if `val' <= 0 { ;
			di "Maximum at age: " `x'; 
			local peak = `x';
			continue, break;
		};
	};
	
	if "`plot'" != "" { ;
	// cohort projection
	twoway (function y = 	 `mat'[1,11] + 
						 `mat'[1,1]*((`cohort' - 1955)/10) + 
						 `mat'[1,2]*((`cohort' - 1955)/10)^2 + 
						 `mat'[1,3]*(x - 45)/10 + 
						 `mat'[1,4]*((x - 45)/10)^2 + 
						 `mat'[1,5]*((x - 45)/10)^3 + 
						 `mat'[1,6]*((x - 45)/10)^4 + 
						 `mat'[1,7]*((x - 45)/10)*(`cohort' - 1955)/10 + 
						 `mat'[1,8]*((x - 45)/10)^2*(`cohort' - 1955)/10, 
						 range(20 80)), xlabel(20(5)80) xline(`peak') xmtick(20(1)80)  title("`model' - `cohort'") name(projection, replace)
						 ;
	// 1st derivative						 
	twoway (function y = `mat'[1,3] + 
	2*`mat'[1,4]*((x - 45)/10) + 
	3*`mat'[1,5]*((x - 45)/10)^2 + 
	4*`mat'[1,6]*((x - 45)/10)^3 + 
	`mat'[1,7]*((`cohort' - 1955)/10) + 
	2*`mat'[1,8]*((`cohort' - 1955)/10)*((x - 45)/10), range(20 80)), yline(0) xline(`peak') xlabel(20(5)80) xmtick(20(1)80) title("1st derivation: `model' - `cohort'") name(deriv, replace) ;

	};
	
	
	
	#delimit cr
	
end

capt program drop gap_peak_age
program define gap_peak_age, rclass
	syntax, Malemodel(name) Femalemodel(name) cohort(integer) [plot]
	
	est restore `femalemodel'
	mat cW = e(b)
	est restore `malemodel'
	mat cM = e(b)
	
	#delimit ;
	
	* Peak. Solve iteratively;
	foreach x of numlist 20(.1)80 { ;
		
		local val = (cW[1,3] - cM[1,3]) + 
		2*(cW[1,4] - cM[1,4])*((`x' - 45)/10) + 
		3*(cW[1,5] - cM[1,5])*((`x' - 45)/10)^2 + 
		4*(cW[1,6] - cM[1,6])*((`x' - 45)/10)^3 + 
		(cW[1,7] - cM[1,7])*((`cohort' - 1955)/10) + 
		2*(cW[1,8] - cM[1,8])*((`cohort' - 1955)/10)*((`x' - 45)/10);
		if `val' <= 0 { ;
			di "Maximum at age: " `x'; 
			local peak = `x';
			continue, break;
		};
	};
	* Gap size in hours; 
	local gap = cW[1,11] - cM[1,11] + 
						 (cW[1,1] - cM[1,1])*((`cohort' - 1955)/10) + 
						 (cW[1,2] - cM[1,2])*((`cohort' - 1955)/10)^2 + 
						 (cW[1,3] - cM[1,3])*(`peak' - 45)/10 + 
						 (cW[1,4] - cM[1,4])*((`peak' - 45)/10)^2 + 
						 (cW[1,5] - cM[1,5])*((`peak' - 45)/10)^3 + 
						 (cW[1,6] - cM[1,6])*((`peak' - 45)/10)^4 + 
						 (cW[1,7] - cM[1,7])*((`peak' - 45)/10)*(`cohort' - 1955)/10 + 
						 (cW[1,8] - cM[1,8])*((`peak' - 45)/10)^2*(`cohort' - 1955)/10;
	di "Gap size (hours): " `gap'; 
	
	* Gap size in hours 35 years after peak;
	local peak35 = `peak'  + 35;
	local gap35 = cW[1,11] - cM[1,11] + 
						 (cW[1,1] - cM[1,1])*((`cohort' - 1955)/10) + 
						 (cW[1,2] - cM[1,2])*((`cohort' - 1955)/10)^2 + 
						 (cW[1,3] - cM[1,3])*(`peak35' - 45)/10 + 
						 (cW[1,4] - cM[1,4])*((`peak35' - 45)/10)^2 + 
						 (cW[1,5] - cM[1,5])*((`peak35' - 45)/10)^3 + 
						 (cW[1,6] - cM[1,6])*((`peak35' - 45)/10)^4 + 
						 (cW[1,7] - cM[1,7])*((`peak35' - 45)/10)*(`cohort' - 1955)/10 + 
						 (cW[1,8] - cM[1,8])*((`peak35' - 45)/10)^2*(`cohort' - 1955)/10;
	di "Gap size (hours) 35 years later: " `gap35'; 
	
	* Plot maximum;
	if "`plot'" != "" { ;
	// cohort projection
	twoway (function y = 	 cW[1,11] - cM[1,11] + 
						 (cW[1,1] - cM[1,1])*((`cohort' - 1955)/10) + 
						 (cW[1,2] - cM[1,2])*((`cohort' - 1955)/10)^2 + 
						 (cW[1,3] - cM[1,3])*(x - 45)/10 + 
						 (cW[1,4] - cM[1,4])*((x - 45)/10)^2 + 
						 (cW[1,5] - cM[1,5])*((x - 45)/10)^3 + 
						 (cW[1,6] - cM[1,6])*((x - 45)/10)^4 + 
						 (cW[1,7] - cM[1,7])*((x - 45)/10)*(`cohort' - 1955)/10 + 
						 (cW[1,8] - cM[1,8])*((x - 45)/10)^2*(`cohort' - 1955)/10, 
						 range(20 80)), name(projection, replace) 
						 xlabel(20(5)80) xline(`peak') xmtick(20(1)80) title("Cohort `cohort'")
						 ;
	// 1st derivative						 
	twoway (function y = (cW[1,3] - cM[1,3]) + 
		2*(cW[1,4] - cM[1,4])*((x - 45)/10) + 
		3*(cW[1,5] - cM[1,5])*((x - 45)/10)^2 + 
		4*(cW[1,6] - cM[1,6])*((x - 45)/10)^3 + 
		(cW[1,7] - cM[1,7])*((`cohort' - 1955)/10) + 
		2*(cW[1,8] - cM[1,8])*((`cohort' - 1955)/10)*((x - 45)/10), range(20 80)), 
		xlabel(20(5)80) xline(`peak') yline(0) xmtick(20(1)80) title("Cohort `cohort'")
		name(deriv, replace) ;
	};	
	
	#delimit cr
	
	return scalar age = `peak'
	return scalar gap = `gap'
	return scalar gap35 = `gap35'
	
end

capt program drop cumulatedhours 
program define cumulatedhours, rclass 
	syntax , model(name) cohort(integer) from(integer) to(integer)
	
	est restore `model' // choose M for male or W for female
	
	mat b = e(b)
	local mat "b"

	#delimit ;

	// Integrate numerically
	local h = 0;
	foreach age of numlist `from'/`to' { ; 
		local h = `h' + `mat'[1,11] + 
							 `mat'[1,1]*((`cohort' - 1955)/10) + 
							 `mat'[1,2]*((`cohort' - 1955)/10)^2 + 
							 `mat'[1,3]*(`age' - 45)/10 + 
							 `mat'[1,4]*((`age' - 45)/10)^2 + 
							 `mat'[1,5]*((`age' - 45)/10)^3 + 
							 `mat'[1,6]*((`age' - 45)/10)^4 + 
							 `mat'[1,7]*((`age' - 45)/10)*(`cohort' - 1955)/10 + 
							 `mat'[1,8]*((`age' - 45)/10)^2*(`cohort' - 1955)/10
							 ;
	}; 
	local cumulated = 52*5*`h'; // accumulated hours
	local average = `h'/(`to' - `from'); // average hours per year
	#delimit cr	
	
	di "Cumulated hours: " `cumulated' 
	di "Average per year: " `average' 
	
	return scalar cumulated = `cumulated'
	return scalar average = `average'
end


log using "${logDir}/numbers_in_manuscript.txt", replace

// Estimate cohort ages by which housework peaked for women born in 40, 50, and 60


// WOMEN 

* 1940: Peak at age 36.4
peak_age , model(Wm8b) cohort(1940) plot
* 1950: Peak at age 35.2
peak_age , model(Wm8b) cohort(1950) plot
* 1960: Peak at age 34
peak_age , model(Wm8b) cohort(1960) plot

* Equivalent to a decline of 1.4 months for each successive year of birth
di 12*(36.4-34)/20 // 1.4(4)

// MEN 

* 1940: Peak at age 73.9
peak_age , model(Mm8b) cohort(1940) // plot
* 1950: Peak at age 71.6
peak_age , model(Mm8b) cohort(1950) // plot
* 1960: Peak at age 68.8
peak_age , model(Mm8b) cohort(1960) // plot

* Equivalent to a decline of 3.1 months for each successive year of birth
di 12*(73.9-68.8)/20 // 3.06


// Age at maximal gender gap at various cohorts
/*
"Second, the gender gap was largest when women’s housework time was at its peak 
and subsequently narrowed in remarkably steady fashion – a life-course convergence 
that lasted approximately 35 years in all cohorts. In the cohort of 1940, 
the average gender gap in housework time declined from a maximum of XX hours at age 
X to XX hours 35 years later; in the cohort of 1950, from a maximum of XX hours at 
age X to XX hours 35 years later; in the cohort of 1960, from a maximum of XX hours 
at age X to XX hours 35 years later." 

Gender gap = E[y_w | age] - [y_m | age] 

*/

	
// Age by which the gender gap peaks 

* 1940 - age = 35.2, gap size (hours) = 5.1, 35 years later = 2 
gap_peak_age, femalemodel(Wm8b) malemodel(Mm8b) cohort(1940) // plot

* 1950 - age = 34.5, gap size (hours) = 4.0, 35 years later = 1.8 
gap_peak_age, femalemodel(Wm8b) malemodel(Mm8b) cohort(1950) // plot

* 1960 - age = 33.7, gap size (hours) = 3.1, 35 years later = 1.6
gap_peak_age, femalemodel(Wm8b) malemodel(Mm8b) cohort(1960) // plot

* In relative terms the gender gap declined by 39%
di 100*(1 - 3.1/5.1) // 39(.21)%

// How many hours of housework time women and men accumulate 
// from age 25 until age 75?



// WOMEN 

* 1940: 65460 
cumulatedhours, model(Wm8b) cohort(1940) from(25) to(75)

* 1950: 57234
cumulatedhours, model(Wm8b) cohort(1950) from(25) to(75)

* 1960: 49208
cumulatedhours, model(Wm8b) cohort(1960) from(25) to(75)

* Absolute cohort change 40 -> 60: -16252
di 65460 - 49208

// MEN 

* 1940: 16856 
cumulatedhours, model(Mm8b) cohort(1940) from(25) to(75)

* 1950: 19036
cumulatedhours, model(Mm8b) cohort(1950) from(25) to(75)

* 1960: 20061
cumulatedhours, model(Mm8b) cohort(1960) from(25) to(75)

* Absolute cohort change 40 -> 60: +3205
di 16856 - 20061

// GAP in rates of cumulated hours

* 1940 – 3.9
di 65460/16856

* 1950 – 3.0
di 57234/19036

* 1960 – 2.5
di 49208/20061

log close



////////////////////
// FIGURE 1. LIFE-COURSE AND COHORT PROFILES OF HOUSEWORK TIME
////////////////////

// Plot 
capt drop Whw Mhw 
rename sy1990 _sy1990
gen sy1990 = 0
est restore Wm8b
predict Whw 

est restore Mm8b
predict Mhw 
drop sy1990
rename _sy1990 sy1990

twoway (line Whw age if gebjahr==1925 & age <=85, sort lcolor(cranberry) lpat(solid)) ///
	   (line Whw age if gebjahr==1935 & age <=85, sort lcolor(cranberry) lpat(solid)) ///
	   (line Whw age if gebjahr==1945, sort lcolor(cranberry) lpat(solid)) ///
	   (line Whw age if gebjahr==1955, sort lcolor(cranberry) lpat(solid)) ///
	   (line Whw age if gebjahr==1965 & age > 22, sort lcolor(cranberry) lpat(solid)) ///
	   (line Whw age if gebjahr==1975 & age > 22, sort lcolor(cranberry) lpat(solid)) ///
	   (line Whw age if gebjahr==1985 & age > 22, sort lcolor(cranberry) lpat(solid)) ///
	   (line Mhw age if gebjahr==1925 & age <=85, sort lcolor(blue) lpat(solid)) ///
	   (line Mhw age if gebjahr==1935 & age <=85, sort lcolor(blue) lpat(solid)) ///
	   (line Mhw age if gebjahr==1945, sort lcolor(blue) lpat(solid)) ///
	   (line Mhw age if gebjahr==1955, sort lcolor(blue) lpat(solid)) ///
	   (line Mhw age if gebjahr==1965 & age > 22, sort lcolor(blue) lpat(solid)) ///
	   (line Mhw age if gebjahr==1975 & age > 22, sort lcolor(blue) lpat(solid)) ///
	   (line Mhw age if gebjahr==1985 & age > 22, sort lcolor(blue) lpat(solid)) ///
	   , name(baseline, replace) legend(off) ylabel(0(1)6, grid glpat(shortdash)) /// 
	     title("") /// 
		 xlabel(20(10)90) xmtick(20(1)90) xtick(20(5)90) ///
		 xtitle(Age) ytitle("Hours on a typical weekday") ///
		 scheme(lean1) ymtick(0(.25)6) ///
		 text(1.8 84 "1925", size(vsmall) col(blue)) /// 
		 text(2.1 78 "1935", size(vsmall) col(blue)) ///
		 text(1.95 68 "1945", size(vsmall) col(blue)) /// 
		 text(1.85 58 "1955", size(vsmall) col(blue)) ///
		 text(1.60 48 "1965", size(vsmall) col(blue)) ///
		 text(1.65 38 "1975", size(vsmall) col(blue)) ///
		 text(1.80 28 "1985", size(vsmall) col(blue)) ///
		 text(2.80 82.5 "1925", size(vsmall) col(cranberry)) /// 
		 text(3.65 78 "1935", size(vsmall) col(cranberry)) ///
		 text(3.95 68 "1945", size(vsmall) col(cranberry)) /// 
		 text(3.35 58 "1955", size(vsmall) col(cranberry)) ///
		 text(2.93 48 "1965", size(vsmall) col(cranberry)) ///
		 text(2.88 38 "1975", size(vsmall) col(cranberry)) ///
		 text(2.65 28 "1985", size(vsmall) col(cranberry)) 

graph export "${logDir}/Figure_1.pdf", replace
graph export "${logDir}/Figure_1.tif", replace
graph export "${logDir}/Figure_1.eps", replace
graph export "${logDir}/Figure_1.ps", replace


///////////////
// FIGURE 2. LIFE-COURSE PROJECTIONS OF HOUSEWORK TIME FOR THREE COHORTS OF WOMEN AND MEN
///////////////

// Plot synthetic life-course projection for cohorts 1940, 50, and 60
* Women and men
foreach cohort of numlist 1940 (10) 1960 {
	// use coefficients
	est restore Wm8b
	mat cW = e(b)
	local mat "cW"
	#delimit ;
	local Wfunction`cohort' "`mat'[1,11] + 
					     `mat'[1,1]*((`cohort' - 1955)/10) + 
						 `mat'[1,2]*((`cohort' - 1955)/10)^2 + 
						 `mat'[1,3]*(x - 45)/10 + 
						 `mat'[1,4]*((x - 45)/10)^2 + 
						 `mat'[1,5]*((x - 45)/10)^3 + 
						 `mat'[1,6]*((x - 45)/10)^4 + 
						 `mat'[1,7]*((x - 45)/10)*(`cohort' - 1955)/10 + 
						 `mat'[1,8]*((x - 45)/10)^2*(`cohort' - 1955)/10";
	#delimit cr
	
	est restore Mm8b
	mat cM = e(b)
	local mat "cM"
	#delimit ;
	local Mfunction`cohort' "`mat'[1,11] + 
					     `mat'[1,1]*((`cohort' - 1955)/10) + 
						 `mat'[1,2]*((`cohort' - 1955)/10)^2 + 
						 `mat'[1,3]*(x - 45)/10 + 
						 `mat'[1,4]*((x - 45)/10)^2 + 
						 `mat'[1,5]*((x - 45)/10)^3 + 
						 `mat'[1,6]*((x - 45)/10)^4 + 
						 `mat'[1,7]*((x - 45)/10)*(`cohort' - 1955)/10 + 
						 `mat'[1,8]*((x - 45)/10)^2*(`cohort' - 1955)/10";
	#delimit cr
		
}	


tabstat age if inlist(gebjahr,1940,1950,1960), by(gebjahr) stats(min max)

twoway  (function y = `Wfunction1940', range(23 85) lcol(cranberry) lpat(shortdash) ) ///
		(function y = `Wfunction1940', range(45 74) lcol(cranberry) lpat(solid) ) ///
		(function y = `Wfunction1950', range(23 85) lcol(cranberry) lpat(shortdash) ) ///
		(function y = `Wfunction1950', range(35 64) lcol(cranberry) lpat(solid) ) ///
		(function y = `Wfunction1960', range(23 85) lcol(cranberry) lpat(shortdash) ) ///
		(function y = `Wfunction1960', range(25 54) lcol(cranberry) lpat(solid) ) ///
		(function y = `Mfunction1940', range(23 85) lcol(blue) lpat(shortdash) ) ///
		(function y = `Mfunction1940', range(45 74) lcol(blue) lpat(solid) ) ///
		(function y = `Mfunction1950', range(23 85) lcol(blue) lpat(shortdash) ) ///
		(function y = `Mfunction1950', range(35 64) lcol(blue) lpat(solid) ) ///
		(function y = `Mfunction1960', range(23 85) lcol(blue) lpat(shortdash) ) ///
		(function y = `Mfunction1960', range(25 54) lcol(blue) lpat(solid) ) ///
		   ,  legend(off) ///
			 xtitle(Age) ytitle("") title("") ///
			 scheme(lean1) xlabel(20(5)85) xmtick(20(1)85) xtick(20(5)85) ylabel(0(1)6) ymtick(0(.25)6) ///
			 name(projection, replace)
			 
graph export "${logDir}/Figure_2.pdf", replace
graph export "${logDir}/Figure_2.eps", replace
graph export "${logDir}/Figure_2.tif", replace
graph export "${logDir}/Figure_2.ps", replace



/////////////////////
// Figure A1. Life-Course and Cohort Profiles of Housework Time (Non-Parametric Curves)
/////////////////////
// Descriptive non-parametric plot
recode gebjahr (1920/1929 = 0 "20/29") ///
			   (1930/1939 = 1 "30/39") /// 
			   (1940/1949 = 2 "40/49") ///
			   (1950/1959 = 3 "50/59") ///
			   (1960/1969 = 4 "60/69") ///
			   (1970/1979 = 5 "70/79") ///
			   (1980/1990 = 6 "80/90") ///
			   , gen(coh)

by coh male age, sort: egen mhw = mean(hw)
capt drop f m
gen f = mhw if male == 0
gen m = mhw if male == 1

twoway (line f age if coh==0 & age <=85, sort lcolor(cranberry*.2) lpat(solid)) ///
	   (line f age if coh==1 & age <=85, sort lcolor(cranberry*.3) lpat(solid)) ///
	   (line f age if coh==2, sort lcolor(cranberry*.4) lpat(solid)) ///
	   (line f age if coh==3, sort lcolor(cranberry*.5) lpat(solid)) ///
	   (line f age if coh==4 & age >= 20, sort lcolor(cranberry*.6) lpat(solid)) ///
	   (line f age if coh==5 & age >= 20, sort lcolor(cranberry*.7) lpat(solid)) ///
	   (line f age if coh==6 & age >= 20, sort lcolor(cranberry) lpat(solid)) ///
	   (line m age if coh==0 & age <=85, sort lcolor(blue*.2) lpat(solid)) ///
	   (line m age if coh==1 & age <=85, sort lcolor(blue*.3) lpat(solid)) ///
	   (line m age if coh==2, sort lcolor(blue*.4) lpat(solid)) ///
	   (line m age if coh==3, sort lcolor(blue*.5) lpat(solid)) ///
	   (line m age if coh==4 & age >= 20, sort lcolor(blue*.6) lpat(solid)) ///
	   (line m age if coh==5 & age >= 20, sort lcolor(blue*.7) lpat(solid)) ///
	   (line m age if coh==6 & age >= 20, sort lcolor(blue) lpat(solid)) ///
	   , name(descriptive, replace) legend(off) ylabel(0(1)6, grid glpat(shortdash)) /// 
	     title("") /// 
		 xlabel(20(10)90) xmtick(20(1)90) xtick(20(5)90) ///
		 xtitle(Age) ytitle("Hours on a typical weekday") ///
		 scheme(lean1) ymtick(0(.25)6) ///
		 note("Averages shown for cohorts 1920/29, 1930/39, ..., 1980/90", size(small))
graph export "${logDir}/Figure_A1.pdf", replace	

